<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
		xmlns:svg="http://www.w3.org/2000/svg">

<xsl:template match="svg">
  <svg:svg viewBox="0 0 {@width} {@height}">
    <svg:g style="stroke: black; fill: white;"
	   transform="translate(0,{@height}) scale(1,-1)">
      <xsl:apply-templates/>
    </svg:g>
  </svg:svg>
</xsl:template>

<xsl:template match="line">
  <svg:line>
    <xsl:copy-of select="@x1 | @y1 | @x2 | @y2"/>
    <xsl:call-template name="copy-style"/>
    <xsl:apply-templates/>
  </svg:line>
</xsl:template>

<xsl:template match="rect">
  <xsl:variable name="x">
    <xsl:choose>
      <xsl:when test="@x1 > @x2"><xsl:value-of select="@x2"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="@x1"/></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="y">
    <xsl:choose>
      <xsl:when test="@y1 > @y2"><xsl:value-of select="@y2"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="@y1"/></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="w">
    <xsl:choose>
      <xsl:when test="@x1 > @x2"><xsl:value-of select="@x1 - @x2"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="@x2 - @x1"/></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="h">
    <xsl:choose>
      <xsl:when test="@y1 > @y2"><xsl:value-of select="@y1 - @y2"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="@y2 - @y1"/></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <svg:rect x="{$x}" y="{$y}" width="{$w}" height="{$h}">
    <xsl:copy-of select="@rx | @ry"/>
    <xsl:call-template name="copy-style"/>
    <xsl:apply-templates/>
  </svg:rect>
</xsl:template>

<xsl:template match="circle">
  <svg:circle>
    <xsl:copy-of select="@cx | @cy | @r"/>
    <xsl:call-template name="copy-style"/>
    <xsl:apply-templates/>
  </svg:circle>
</xsl:template>

<xsl:template match="ellipse">
  <svg:ellipse>
    <xsl:copy-of select="@cx | @cy | @rx | @ry"/>
    <xsl:call-template name="copy-style"/>
    <xsl:apply-templates/>
  </svg:ellipse>
</xsl:template>

<xsl:template match="g">
  <svg:g>
    <xsl:call-template name="copy-style"/>
    <xsl:apply-templates/>
  </svg:g>
</xsl:template>

<xsl:template name="copy-style">
  <xsl:if test="@color | @fill | @stroke">
    <xsl:attribute name="style">
      <xsl:if test="@color">stroke: <xsl:value-of select="@color"/>;</xsl:if>
      <xsl:if test="@fill">fill: <xsl:value-of select="@fill"/>;</xsl:if>
      <xsl:if test="@stroke">stroke-width: <xsl:value-of select="@stroke"/>px;</xsl:if>
    </xsl:attribute>
  </xsl:if>
</xsl:template>
  
</xsl:stylesheet>